import React from 'react'
import {Container, Row, Col} from 'react-bootstrap'

import RoundDisplay from './RoundDisplay'
import { PosedLeftToRight, PosedRightToLeft, PosedDropIn } from '../util/PosedPresets'
import RoundsHelper from '../util/RoundsHelper'
import RoundHelper from '../util/RoundHelper'
import Winner from '../util/Winner'

import imageFighterRed from '../images/fighter_left.png'
import imageFighterBlue from '../images/fighter_right.png'

export default class FightDisplay extends React.Component {

    getImageOverlayRed = (lastRound) => {
        if (lastRound !== undefined) {
            const point = lastRound.red
            if (point.type === 'status' && point.value === 0) {
                return (
                    <div>
                        <div className={'fighter-image-overlay'}/>
                        <div className={'fighter-image-overlay-text text-gray py-3 bg-red'}>
                            {point.long}
                        </div>
                    </div>
                )
            } else {
                const roundHelper = new RoundHelper(lastRound)
                if (roundHelper.getWinner() === Winner.BLUE) {
                    return <div className={'fighter-image-overlay'}/>
                }
            }
        }
    }

    getImageOverlayBlue = (lastRound) => {
        if (lastRound !== undefined) {
            const point = lastRound.blue
            if (point.type === 'status' && point.value === 0) {
                return (
                    <div>
                        <div className={'fighter-image-overlay'}/>
                        <div className={'fighter-image-overlay-text text-gray py-3 bg-blue'}>
                            {point.long}
                        </div>
                    </div>
                )
            } else {
                const roundHelper = new RoundHelper(lastRound)
                if (roundHelper.getWinner() === Winner.RED) {
                    return <div className={'fighter-image-overlay'}/>
                }
            }
        }
    }

    render() {
        console.log('hllo')
        const roundsHelper = new RoundsHelper(this.props.fight.rounds)
        const winner = roundsHelper.getWinner()
        const lastRound = roundsHelper.getLastRound()

        return (
            <Container 
                fluid={true} 
                className={'text-white font-weight-bold font-size-display pt-5'} >
                <Row className={''}>
                    <Col sm={4} className={''}>
                        <PosedLeftToRight className={'text-left pl-5'} initialPose={'hidden'} pose={'visible'} i={0}>
                            {this.props.fight.red}
                            <div className={'fighter-image'}>
                            <img src={imageFighterRed} alt={'red fighter: ' + this.props.fight.red} className={winner === Winner.RED ? 'img-fluid animation-winner-red' : 'img-fluid'}/>
                                {this.getImageOverlayRed(lastRound)}
                            </div>
                        </PosedLeftToRight>
                    </Col>
                    <Col sm={4} className={''}>
                        <PosedDropIn className={'text-center'} initialPose={'ready'} pose={'drop'} i={4}>
                            <RoundDisplay data={this.props.fight.rounds} />
                        </PosedDropIn>
                    </Col>
                    <Col sm={4} className={''}>
                        <PosedRightToLeft className={'text-right pr-5'} initialPose={'hidden'} pose={'visible'} i={0}>
                            {this.props.fight.blue}
                            <div className={'fighter-image'}>
                            <img src={imageFighterBlue} alt={'blue fighter: ' + this.props.fight.blue} className={winner === Winner.BLUE ? 'img-fluid animation-winner-blue' : 'img-fluid'}/>
                                {this.getImageOverlayBlue(lastRound)}
                            </div>
                        </PosedRightToLeft>
                    </Col>
                </Row>
            </Container>
        )
    }
}