import React from 'react'
import {Container, Row, Col} from 'react-bootstrap'
import Flags from './Flags'
import { PosedBottomToTop } from '../util/PosedPresets'
import FightsHelper from './../util/FightsHelper'
import RoundsHelper from './../util/RoundsHelper'
import Winner from './../util/Winner'

const classNameContainer = 'text-black text-center font-weight-bold'
const classNameRed = 'font-size-fight-overview-fighter text-white bg-red border border-white border-3 rounded'
const classNameBlue = 'font-size-fight-overview-fighter text-white bg-blue border border-white border-3 rounded'
const classNameCurrent = 'font-size-fight-overview-current text-white bg-black border border-white border-3 rounded py-2 my-1 animation-pulse-white'
const classNameNeutral = 'font-size-fight-overview-fighter bg-white border border-black border-3 rounded'
const classNameCategory = 'text-center text-black font-weight-bold bg-white-linear-gradient font-size-fight-overview-category p-0 mt-4 mb-2'

export default class FightOverview extends React.Component {

    componentDidMount() {
        this.scroll()
    }

    componentDidUpdate() {
        this.scroll()
    }

    scroll = () => {
        window.scrollTo(0, 0);
        setTimeout(() => {
            const scrollTo = document.querySelector('.scroll-to');
            /* 0000385: TypeError: Cannot read property 'scrollIntoView' of null */
            if (scrollTo !== null) {
                scrollTo.scrollIntoView({ 
                    behavior: 'smooth'
                })
            }
        }, 2500)
    }

    flag = (code) => {
        if (code.length > 0) {
            return <Flags code={code} size='lg'/>
        } else {
            return <span style={{visibility: 'hidden'}}><Flags code={'de'} size='lg' /></span> // FIXME
        }
    }

    getFightDisplay = (fight) => {
        return (
            <Container key={'display-' + fight.id} className={classNameContainer}>
                <Row className={'justify-content-md-center align-items-center'}>
                    <Col className={'col-auto p-0 m-0'}>
                        {this.flag(this.fightsHelper.getRedCountry(fight.id))}
                    </Col>
                    <Col className={''} >
                        <div className={this.getRedClassName(fight)}>
                            {this.fightsHelper.getRed(fight.id)}
                        </div>
                    </Col>
                    <Col sm={1} className={'px-1'}>
                        <div className={this.getNumberClassName(fight)}>
                            {fight.number}
                        </div>
                    </Col>
                    <Col className={''} >
                        <div className={this.getBlueClassName(fight)}>
                            {this.fightsHelper.getBlue(fight.id)}
                        </div>
                    </Col>
                    <Col className={'col-auto p-0 m-0'}>
                        {this.flag(this.fightsHelper.getBlueCountry(fight.id))}
                    </Col>
                </Row>
            </Container>
        )
    }

    getRedClassName = (fight) => {
        if (this.fightsHelper.isCurrent(fight.id)) {
            return classNameCurrent
        } else if (this.roundsHelper.getWinner() === Winner.RED) {
            return classNameRed
        } else {
            return classNameNeutral
        }
    }

    getNumberClassName = (fight) => {
        if (this.fightsHelper.isCurrent(fight.id)) {
            return classNameCurrent
        } else if (this.roundsHelper.getWinner() === Winner.BLUE) {
            return classNameBlue
        } else if (this.roundsHelper.getWinner() === Winner.RED) {
            return classNameRed
        } else {
            return classNameNeutral
        }
    }

    getBlueClassName = (fight) => {
        if (this.fightsHelper.isCurrent(fight.id)) {
            return classNameCurrent
        } else if (this.roundsHelper.getWinner() === Winner.BLUE) {
            return classNameBlue
        } else {
            return classNameNeutral
        }
    }

    getFightCatagory = (fight) => {
        /* do not display category if the fight before is of the same category */
        if (this.printCategory(fight)) {
            const scrollTo = this.isCategoryCurrent(fight) ? ' scroll-to' : ''
            return (
                <div key={'category-' + fight.id} className={classNameCategory + scrollTo}>
                    {fight.category}
                </div>
            )
        }
    }

    printCategory = (fight) => {
        const index = this.props.fights.findIndex(element => element.id === fight.id)
        const precedingFight = this.props.fights[index - 1]
        return precedingFight === undefined || fight.category !== precedingFight.category
    }

    isCategoryCurrent = (fight) => {
        const start = this.props.fights.findIndex(element => element.id === fight.id)
        const endIndex = this.props.fights.slice(start).findIndex(element => element.category !== fight.category)
        const end = (endIndex === -1) ? this.props.fights.length : start + endIndex
        return this.props.fights
               .slice(start, end)
               .find(element => this.fightsHelper.isCurrent(element.id)) !== undefined
    }

    renderFight = (fight, index) => {
        this.roundsHelper = new RoundsHelper(fight.rounds)
        return (
            <PosedBottomToTop key={'wrapper-' + fight.id} className={'m-2'} initialPose={'hidden'} pose={'visible'} i={index}>
                {this.getFightCatagory(fight)}
                {this.getFightDisplay(fight)}
            </PosedBottomToTop>
        )
    }

    renderFights = (fights) => fights.map((fight, index) => this.renderFight(fight, index))

    render() {
        this.fightsHelper = new FightsHelper(this.props.fights)
        return (
            <div className={'mx-4 my-5 font-size-overview'}>
                {this.renderFights(this.props.fights)}
            </div>
        )
    }
}