import React from 'react'
import {Container, Row, Col} from 'react-bootstrap'
import { PosedDropInImg } from '../util/PosedPresets'

import RoundHelper from './../util/RoundHelper'

import Point from '../images/point.svg'

const MAX_POINTS = 5

// https://popmotion.io/pose/


const createPoints = (points, keyPrefix) => {
    let result = []
    if (points.type === 'point') {
        for (let i = 0; i < MAX_POINTS; i++) {
            const className = i < points.value ? '' : 'invisible'
            result.push(
                <Col key={`point-${keyPrefix}-${i}`} sm={1} className={''}>
                    <PosedDropInImg
                        src={Point}
                        alt={'Point'} 
                        key={keyPrefix + '-' + i + 1} 
                        className={className}
                        height={"32px"}
                        style={{marginLeft: '-11px', marginBottom: '12px'}}
                        initialPose={'hidden'} 
                        pose={'visible'} 
                        i={i} />
                </Col>
            )
        }
    } else {
        result.push(
            <Col key={`point-${keyPrefix}-0`} sm={5} className={''} >
                {points.display}
            </Col>
        )
    }

    return result
}

const createRoundNumer = (number) => {
    return (
        <Col sm={2} className={''}>
            {number}
        </Col>
    )
}

function RoundResult(props) {
    const roundHelper = new RoundHelper(props.result)
    return (
        <div className={roundHelper.getWinner().bg + ' round-result m-2 border border-white border-3 rounded'}>
            <Container>
                <Row className={''}>
                    {createPoints(props.result.red, 'redPoint').reverse()}
                    {createRoundNumer(props.number)}
                    {createPoints(props.result.blue, 'bluePoint')}
                </Row>
            </Container>
        </div>
    )
}

export default RoundResult