import React from 'react'
import {Container, Row, Col} from 'react-bootstrap'
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import { faExclamationCircle } from '@fortawesome/free-solid-svg-icons'
import { faFistRaised } from '@fortawesome/free-solid-svg-icons'
import Constants from './../util/Constants'
import { PosedDropIn } from '../util/PosedPresets'

const createWarnings = (warnings, keyPrefix) => {
    const value = warnings && warnings.value ? warnings.value : 0
    let result = []
    for (let i = 0; i < Constants.MAX_WARNINGS; i++) {
        if (i >= value ) {
            // wird nicht dargestellt
            result.push(
                <Col key={keyPrefix + '-' + i + 1} sm={4} className={''}>
                    <div className={'text-white icon-size-warning invisible'}>
                        <FontAwesomeIcon icon={faExclamationCircle}/>
                    </div>
                </Col>
            )
        } else {
            if (i === value - 1) {
                // neue Verwarnung
                result.push(
                    <Col key={keyPrefix + '-' + i + 1} sm={4} className={''}>
                        <PosedDropIn 
                            className={'text-white icon-size-warning'}
                            initialPose={'ready'}
                            pose={'drop'}
                            i={0}>
                                <FontAwesomeIcon icon={faExclamationCircle}/>
                        </PosedDropIn>
                    </Col>
                )
            } else {
                // bestehende Verwarnung
                result.push(
                    <Col key={keyPrefix + '-' + i + 1} sm={4} className={''}>
                        <div className={'text-white icon-size-warning'}>
                            <FontAwesomeIcon icon={faExclamationCircle}/>
                        </div>
                    </Col>
                )
            }
        }
    }
    return result
}

function Warnings(props) {
    const warnings = props.data.warnings
    return (
        <div className={'bg-black m-2 border border-white border-3 rounded'}>
            <Container>
                <Row className={'p-2 align-items-center'}>
                    <Col sm={5} className={''}>
                        <Row className={'align-items-center'}>
                            {createWarnings(warnings.red, 'red-warnings').reverse()}
                        </Row>
                    </Col>
                    <Col sm={2} className={''}>
                        <FontAwesomeIcon icon={faFistRaised} style={{fontSize: '2.5rem', paddingBottom: '6px'}} className={'text-white'}/>
                    </Col>
                    <Col sm={5} className={''}>
                        <Row>
                            {createWarnings(warnings.blue, 'red-warnings')}
                        </Row>
                    </Col>
                </Row>
            </Container>
        </div>
    )
}

export default Warnings