import React, { Component } from 'react'
import {Container, Row, Col} from 'react-bootstrap'
import { PosedLeftToRight, PosedRightToLeft, PosedDropIn } from '../util/PosedPresets'
import StartHelper from './../util/StartHelper'
import Constants from './../util/Constants'

export default class StartJudging extends Component {

    getJudgingSingleClassName(value, index, result) {
        if (result) {
            if (index === 0 || index === 4) {
                if (value  === Constants.EMPTY) {
                    return 'rounded p-1 m-1 bg-lightgray'
                } else {
                    return 'rounded p-1 m-1 bg-lightgray font-linethrough'
                }
            }
            return 'rounded p-1 m-1 bg-white'
        } else {
            return 'rounded p-1 m-1 bg-white'
        }
    }

    getJudgingSingleArray(start, result) {
        if (result) {
            const sortedResults = new StartHelper(start).sortByResults()
            switch (sortedResults.length) {
                case 0:
                    return [Constants.EMPTY, Constants.EMPTY, Constants.EMPTY, Constants.EMPTY, Constants.EMPTY]
                case 1:
                    return [Constants.EMPTY, Constants.EMPTY, sortedResults[0].toFixed(2), Constants.EMPTY, Constants.EMPTY]
                case 2:
                    return [Constants.EMPTY, sortedResults[0].toFixed(2), sortedResults[1].toFixed(2), Constants.EMPTY, Constants.EMPTY]
                case 3:
                    return [Constants.EMPTY, sortedResults[0].toFixed(2), sortedResults[1].toFixed(2), sortedResults[2].toFixed(2), Constants.EMPTY]
                case 4:
                    return [sortedResults[0].toFixed(2), sortedResults[1].toFixed(2), sortedResults[2].toFixed(2), sortedResults[3].toFixed(2), Constants.EMPTY]
                case 5:
                    return [sortedResults[0].toFixed(2), sortedResults[1].toFixed(2), sortedResults[2].toFixed(2), sortedResults[3].toFixed(2), sortedResults[4].toFixed(2)]
                default:
                    return [Constants.EMPTY, Constants.EMPTY, Constants.EMPTY, Constants.EMPTY, Constants.EMPTY]
            }
        } else {
            if (start.results.length === 0) {
                return [Constants.EMPTY, Constants.EMPTY, Constants.EMPTY, Constants.EMPTY, Constants.EMPTY]
            }
            return start.results.map(result => result === '' ? Constants.EMPTY : result.toFixed(2))
        }
    }

    getJudgingSingle(start, result) {
        const singleArray = this.getJudgingSingleArray(start, result)
        return singleArray.map((value, index) =>(
            <Row key={index}>
                <Col>
                    <PosedLeftToRight 
                        className={this.getJudgingSingleClassName(value, index, result)}
                        initialPose={'hidden'} 
                        pose={'visible'} 
                        i={index}>
                            {this.getJudgingSingleValue(singleArray, value, index, result)}
                    </PosedLeftToRight>
                </Col>
            </Row>
        ))
    }

    getJudgingSingleValue(singleArray, value, index, result) {
        if (result || value === Constants.EMPTY) {
            return value
        } else {
            if (singleArray.find((v, i) => i === index + 1 && v === Constants.EMPTY) !== undefined) {
                return (
                    <PosedDropIn initialPose={'ready'} pose={'drop'} i={0}>
                        {value}
                    </PosedDropIn>
                )
            }
            return value
        }
    }

    getJudgingResult(start, result) {
        return result 
            ?
                <PosedDropIn className={''} initialPose={'ready'} pose={'drop'} i={0}>
                    {new StartHelper(start).getOverallStandingDisplay()}
                </PosedDropIn>
            :
                'Judging...'
    }

    render() {
        return (
            <Container className={'text-center text-black font-weight-bold bg-black'}>
                <Row className={'align-items-center'}>
                    <Col sm={4} className={'font-size-form-judging-single'}>
                        {this.getJudgingSingle(this.props.start, this.props.result)}
                    </Col>
                    <Col sm={8} className={'font-size-form-judging-overall'}>
                        <PosedRightToLeft className={'rounded m-1 padding-judging bg-white animation-pulse-white'} initialPose={'hidden'} pose={'visible'} i={5}>
                            {this.getJudgingResult(this.props.start, this.props.result)}
                        </PosedRightToLeft>
                    </Col>
                </Row>
            </Container>
        )
    }
}