import React from 'react'
import StopWatchState from './../util/StopWatchState'

class StopWatch extends React.Component {
    constructor(props) {
        super(props)
        this.state = {
            number: props.number,
            time: props.data.start,
            state: props.data.state // current state -> prevents repeated self-calls
        }
    }

    play() {
        this.interval = setInterval(() => {
            this.setState(previous => ({
                time: previous.time - 10
            }))
        }, 10)
    }

    pause() {
        clearInterval(this.interval)
        this.interval = undefined
    }

    handleState() {
        if (this.props.number !== this.state.number) {
            this.setState({
                time: this.props.data.start,
                number: this.props.number
            })
        }

        const play = this.props.data.state === StopWatchState.PLAY && this.state.state === StopWatchState.PAUSE
        const pause = this.props.data.state === StopWatchState.PAUSE && this.state.state === StopWatchState.PLAY

        if (play || pause) {
            this.setState((previous, props) => ({
                time: props.data.time,
                state: props.data.state
            }))
        }

        if (play) {
            this.play()
        } else if (pause) {
            this.pause()
        }
        
    }

    componentWillUnmount() {
        this.pause()
    }

    format(value) {
         // 180000 => 3:00:00
         let milliseconds = parseInt((value % 1000) / 10)
         milliseconds = (milliseconds < 10) ? "0" + milliseconds : milliseconds

         let seconds = Math.floor((value / 1000) % 60)
         seconds = (seconds < 10) ? "0" + seconds : seconds

         const minutes = Math.floor((value / (1000 * 60)) % 60)

         return `${minutes}:${seconds}:${milliseconds}`
    }

    render() {
        this.handleState()
        const {time} = this.state
        return (
            <div>{this.format(time)}</div>
        )
    }
}

export default StopWatch