import FormHelper from './../util/FormHelper'

it('new FormHelper()', () => {
  const formHelper = new FormHelper()
  expect(formHelper).toBeDefined()
})

it('isFinished()', () => {
  expect(new FormHelper(forms_solo_empty).isFinished()).toBe(false)
  expect(new FormHelper(forms_solo_ongoing).isFinished()).toBe(false)
  expect(new FormHelper(forms_solo_finished).isFinished()).toBe(true)
  expect(new FormHelper(forms_solo_empty_disabled).isFinished()).toBe(false)
  expect(new FormHelper(forms_solo_ongoing_disabled).isFinished()).toBe(false)
  expect(new FormHelper(forms_solo_finished_disabled).isFinished()).toBe(true)
  expect(new FormHelper(form_partner_empty).isFinished()).toBe(false)
  expect(new FormHelper(form_partner_ongoing).isFinished()).toBe(false)
  expect(new FormHelper(form_partner_finished).isFinished()).toBe(true)
})

it('sortByPlacement()', () => {
  expect(new FormHelper(forms_solo_empty).sortByPlacement()).toStrictEqual(forms_solo_empty)
  expect(new FormHelper(forms_solo_ongoing).sortByPlacement()).toStrictEqual(forms_solo_ongoing_sorted)
  expect(new FormHelper(forms_solo_finished).sortByPlacement()).toStrictEqual(forms_solo_finished_sorted)
  expect(new FormHelper(forms_solo_empty_disabled).sortByPlacement()).toStrictEqual(forms_solo_empty_disabled_sorted)
  expect(new FormHelper(forms_solo_ongoing_disabled).sortByPlacement()).toStrictEqual(forms_solo_ongoing_disabled_sorted)
  expect(new FormHelper(forms_solo_finished_disabled).sortByPlacement()).toStrictEqual(forms_solo_finished_disabled_sorted)
  expect(new FormHelper(form_partner_empty).sortByPlacement()).toStrictEqual(form_partner_empty)
  expect(new FormHelper(forms_5_decided_by_overall).sortByPlacement()).toStrictEqual(forms_5_decided_by_overall_sorted)
  expect(new FormHelper(forms_5_decided_by_including_highest_and_lowest).sortByPlacement()).toStrictEqual(forms_5_decided_by_including_highest_and_lowest_sorted)
  expect(new FormHelper(forms_5_decided_by_highest_rating_1).sortByPlacement()).toStrictEqual(forms_5_decided_by_highest_rating_1_sorted)
  expect(new FormHelper(forms_5_decided_by_highest_rating_2).sortByPlacement()).toStrictEqual(forms_5_decided_by_highest_rating_2_sorted)
  expect(new FormHelper(forms_5_undecided).sortByPlacement()).toStrictEqual(forms_5_undecided)
  expect(new FormHelper(forms_3_decided_by_overall).sortByPlacement()).toStrictEqual(forms_3_decided_by_overall_sorted)
  expect(new FormHelper(forms_3_decided_by_highest_rating_1).sortByPlacement()).toStrictEqual(forms_3_decided_by_highest_rating_1_sorted)
  expect(new FormHelper(forms_3_decided_by_highest_rating_2).sortByPlacement()).toStrictEqual(forms_3_decided_by_highest_rating_2_sorted)
  expect(new FormHelper(forms_3_undecided).sortByPlacement()).toStrictEqual(forms_3_undecided)
})

it('getTop3()', () => {
  expect(new FormHelper(forms_solo_empty).getTop3()).toStrictEqual([])
  expect(new FormHelper(forms_solo_ongoing).getTop3()).toStrictEqual([forms_solo_ongoing.starts[2], forms_solo_ongoing.starts[0]])
  expect(new FormHelper(forms_solo_finished).getTop3()).toStrictEqual([forms_solo_finished.starts[2], forms_solo_finished.starts[1], forms_solo_finished.starts[0]])
  expect(new FormHelper(forms_solo_empty_disabled).getTop3()).toStrictEqual([])
  expect(new FormHelper(forms_solo_ongoing_disabled).getTop3()).toStrictEqual([forms_solo_ongoing_disabled.starts[0]])
  expect(new FormHelper(forms_solo_finished_disabled).getTop3()).toStrictEqual([forms_solo_finished_disabled.starts[1], forms_solo_finished_disabled.starts[0]])
  expect(new FormHelper(form_partner_empty).getTop3()).toStrictEqual([])
  expect(new FormHelper(form_partner_ongoing).getTop3()).toStrictEqual([form_partner_ongoing.starts[0]])
  expect(new FormHelper(form_partner_finished).getTop3()).toStrictEqual([form_partner_finished.starts[1], form_partner_finished.starts[0]])
  expect(new FormHelper(forms_solo_big_finished).getTop3()).toStrictEqual([forms_solo_big_finished.starts[2], forms_solo_big_finished.starts[1], forms_solo_big_finished.starts[0]])
  expect(new FormHelper(forms_5_decided_by_overall).getTop3()).toStrictEqual([forms_5_decided_by_overall.starts[1], forms_5_decided_by_overall.starts[0]])
  expect(new FormHelper(forms_5_decided_by_including_highest_and_lowest).getTop3()).toStrictEqual([forms_5_decided_by_including_highest_and_lowest.starts[1], forms_5_decided_by_including_highest_and_lowest.starts[0]])
  expect(new FormHelper(forms_5_decided_by_highest_rating_1).getTop3()).toStrictEqual([forms_5_decided_by_highest_rating_1.starts[1], forms_5_decided_by_highest_rating_1.starts[0]])
  expect(new FormHelper(forms_5_decided_by_highest_rating_2).getTop3()).toStrictEqual([forms_5_decided_by_highest_rating_2.starts[1], forms_5_decided_by_highest_rating_2.starts[0]])
  expect(new FormHelper(forms_5_undecided).getTop3()).toStrictEqual([forms_5_undecided.starts[0], forms_5_undecided.starts[1]])
  expect(new FormHelper(forms_3_decided_by_overall).getTop3()).toStrictEqual([forms_3_decided_by_overall.starts[1], forms_3_decided_by_overall.starts[0]])
  expect(new FormHelper(forms_3_decided_by_highest_rating_1).getTop3()).toStrictEqual([forms_3_decided_by_highest_rating_1.starts[1], forms_3_decided_by_highest_rating_1.starts[0]])
  expect(new FormHelper(forms_3_decided_by_highest_rating_2).getTop3()).toStrictEqual([forms_3_decided_by_highest_rating_2.starts[1], forms_3_decided_by_highest_rating_2.starts[0]])
  expect(new FormHelper(forms_3_undecided).getTop3()).toStrictEqual([forms_3_undecided.starts[0], forms_3_undecided.starts[1]])
})

it('getNext()', () => {
  expect(new FormHelper(forms_solo_empty).getNext()).toBe(forms_solo_empty.starts[0])
  expect(new FormHelper(forms_solo_ongoing).getNext()).toBe(forms_solo_ongoing.starts[1])
  expect(new FormHelper(forms_solo_finished).getNext()).toBe(undefined)
  expect(new FormHelper(forms_solo_empty_disabled).getNext()).toBe(forms_solo_empty_disabled.starts[0])
  expect(new FormHelper(forms_solo_ongoing_disabled).getNext()).toBe(forms_solo_ongoing_disabled.starts[2])
  expect(new FormHelper(forms_solo_finished_disabled).getNext()).toBe(undefined)
  expect(new FormHelper(form_partner_empty).getNext()).toBe(form_partner_empty.starts[0])
  expect(new FormHelper(form_partner_ongoing).getNext()).toBe(form_partner_ongoing.starts[1])
  expect(new FormHelper(form_partner_finished).getNext()).toBe(undefined)
  expect(new FormHelper(forms_solo_big_finished).getNext()).toBe(undefined)
})

//---------------------------------------

const forms_solo_empty = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Lukas Maier'
      ],
      results: []
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: []
    },
    {
      competitors: [
        'Jessica Maier'
      ],
      results: []
    },
  ]
}

const forms_solo_ongoing = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.51,
        9.15,
        9.98
      ]
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: []
    },
    {
      competitors: [
        'Jessica Maier'
      ],
      results: [
        9.51,
        9.35,
        9.98
      ]
    },
  ]
}

const forms_solo_ongoing_sorted = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Jessica Maier'
      ],
      results: [
        9.51,
        9.35,
        9.98
      ]
    },
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.51,
        9.15,
        9.98
      ]
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: []
    },
  ]
}

const forms_solo_finished = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Jessica Maier'
      ],
      results: [
        9.11,
        9.25,
        9.38
      ]
    },
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.51,
        9.15,
        9.98
      ]
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        9.71,
        9.65,
        9.58
      ]
    },
  ]
}

const forms_solo_finished_sorted = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        9.71,
        9.65,
        9.58
      ]
    },
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.51,
        9.15,
        9.98
      ]
    },
    {
      competitors: [
        'Jessica Maier'
      ],
      results: [
        9.11,
        9.25,
        9.38
      ]
    },
  ]
}

//---------------------------------------

const forms_solo_empty_disabled = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Lukas Maier'
      ],
      results: []
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [],
      disabled: true
    },
    {
      competitors: [
        'Jessica Maier'
      ],
      results: []
    },
  ]
}

const forms_solo_empty_disabled_sorted = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Lukas Maier'
      ],
      results: []
    },
    {
      competitors: [
        'Jessica Maier'
      ],
      results: []
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [],
      disabled: true
    },
  ]
}

const forms_solo_ongoing_disabled = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.51,
        9.15,
        9.98
      ]
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [],
      disabled: true
    },
    {
      competitors: [
        'Jessica Maier'
      ],
      results: []
    },
  ]
}

const forms_solo_ongoing_disabled_sorted = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.51,
        9.15,
        9.98
      ]
    },
    {
      competitors: [
        'Jessica Maier'
      ],
      results: []
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [],
      disabled: true
    },
  ]
}

const forms_solo_finished_disabled = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Jessica Maier'
      ],
      results: [
        9.11,
        9.25,
        9.38
      ]
    },
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.51,
        9.15,
        9.98
      ]
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [],
      disabled: true
    },
  ]
}

const forms_solo_finished_disabled_sorted = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.51,
        9.15,
        9.98
      ]
    },
    {
      competitors: [
        'Jessica Maier'
      ],
      results: [
        9.11,
        9.25,
        9.38
      ]
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [],
      disabled: true
    },
  ]
}

//---------------------------------------

const form_partner_empty = {
  id: 'form-2',
  category: "Partnerform Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 2,
  starts: [
    {
      competitors: [
        'Lukas Maier',
        'Thomas Achorner'
      ],
      results: []
    },
    {
      competitors: [
        'Pascal Mörwald',
        'Manuella Kling'
      ],
      results: []
    }
  ]
}

const form_partner_ongoing = {
  id: 'form-2',
  category: "Partnerform Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 2,
  starts: [
    {
      competitors: [
        'Lukas Maier',
        'Thomas Achorner'
      ],
      results: [
        9.51,
        9.15,
        9.98
      ]
    },
    {
      competitors: [
        'Pascal Mörwald',
        'Manuella Kling'
      ],
      results: []
    }
  ]
}

const form_partner_finished = {
  id: 'form-2',
  category: "Partnerform Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 2,
  starts: [
    {
      competitors: [
        'Lukas Maier',
        'Thomas Achorner'
      ],
      results: [
        9.51,
        9.15,
        9.98
      ]
    },
    {
      competitors: [
        'Pascal Mörwald',
        'Manuella Kling'
      ],
      results: [
        9.61,
        9.75,
        9.48
      ]
    }
  ]
}

const forms_solo_big_finished = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Jessica Maier'
      ],
      results: [
        9.11,
        9.25,
        9.38
      ]
    },
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.51,
        9.15,
        9.98
      ]
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        9.71,
        9.65,
        9.58
      ]
    },
    {
      competitors: [
        'Thorsten Treffer'
      ],
      results: [
        8.71,
        8.65,
        8.58
      ]
    },
    {
      competitors: [
        'Peter Treffer'
      ],
      results: [
        7.71,
        7.65,
        7.58
      ]
    },
    {
      competitors: [
        'Thomas Treffer'
      ],
      results: [
        6.71,
        6.65,
        6.58
      ]
    },
  ]
}

//---------------------------------------

const forms_5_decided_by_overall = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        8.00,
        7.00,
        6.00,
        5.00,
        4.00,
      ]
    },
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.00,
        8.00,
        7.00,
        6.00,
        5.00,
      ]
    },
  ]
}

const forms_5_decided_by_overall_sorted = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.00,
        8.00,
        7.00,
        6.00,
        5.00,
      ]
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        8.00,
        7.00,
        6.00,
        5.00,
        4.00,
      ]
    },
  ]
}

const forms_5_decided_by_including_highest_and_lowest = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        8.00,
        7.00,
        6.00,
        5.00,
        4.00,
      ]
    },
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.00,
        7.00,
        6.00,
        5.00,
        4.00,
      ]
    },
  ]
}

const forms_5_decided_by_including_highest_and_lowest_sorted = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.00,
        7.00,
        6.00,
        5.00,
        4.00,
      ]
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        8.00,
        7.00,
        6.00,
        5.00,
        4.00,
      ]
    },
  ]
}

const forms_5_decided_by_highest_rating_1 = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        2.00,
        3.00,
        4.00,
        5.00,
        6.00,
      ]
    },
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        1.00,
        3.00,
        4.00,
        5.00,
        7.00,
      ]
    },
  ]
}

const forms_5_decided_by_highest_rating_1_sorted = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        1.00,
        3.00,
        4.00,
        5.00,
        7.00,
      ]
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        2.00,
        3.00,
        4.00,
        5.00,
        6.00,
      ]
    }
  ]
}

const forms_5_decided_by_highest_rating_2 = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        2.00,
        3.30,
        3.70,
        5.00,
        6.00,
      ]
    },
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        2.00,
        3.20,
        3.80,
        5.00,
        6.00,
      ]
    },
  ]
}

const forms_5_decided_by_highest_rating_2_sorted = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        2.00,
        3.20,
        3.80,
        5.00,
        6.00,
      ]
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        2.00,
        3.30,
        3.70,
        5.00,
        6.00,
      ]
    },
  ]
}

const forms_5_undecided = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        2.00,
        3.00,
        4.00,
        5.00,
        6.00,
      ]
    },
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        2.00,
        3.00,
        4.00,
        5.00,
        6.00,
      ]
    },
  ]
}

//---------------------------------------

const forms_3_decided_by_overall = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        8.00,
        7.00,
        6.00,
      ]
    },
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.00,
        8.00,
        7.00,
      ]
    },
  ]
}

const forms_3_decided_by_overall_sorted = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        9.00,
        8.00,
        7.00,
      ]
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        8.00,
        7.00,
        6.00,
      ]
    },
  ]
}

const forms_3_decided_by_highest_rating_1 = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        2.00,
        3.00,
        4.00,
      ]
    },
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        1.00,
        3.00,
        5.00,
      ]
    },
  ]
}

const forms_3_decided_by_highest_rating_1_sorted = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        1.00,
        3.00,
        5.00,
      ]
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        2.00,
        3.00,
        4.00,
      ]
    }
  ]
}

const forms_3_decided_by_highest_rating_2 = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        2.02,
        2.98,
        4.00,
      ]
    },
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        1.98,
        3.02,
        4.00,
      ]
    },
  ]
}

const forms_3_decided_by_highest_rating_2_sorted = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        1.98,
        3.02,
        4.00,
      ]
    },
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        2.02,
        2.98,
        4.00,
      ]
    },
  ]
}

const forms_3_undecided = {
  id: 'form-1',
  category: "Handform Nordstil, Jugendliche 8 bis 12 Jahre",
  ring: 1,
  starts: [
    {
      competitors: [
        'Thomas Achorner'
      ],
      results: [
        2.00,
        3.00,
        4.00,
      ]
    },
    {
      competitors: [
        'Lukas Maier'
      ],
      results: [
        2.00,
        3.00,
        4.00,
      ]
    },
  ]
}