import RoundsHelper from './../util/RoundsHelper'
import Point from './../util/Point'
import Winner from './../util/Winner'

it('new RoundsHelper()', () => {
  const roundsHelper = new RoundsHelper()
  expect(roundsHelper).toBeDefined()
})

it('getCurrentRoundNumber()', () => {
  expect(new RoundsHelper(rounds_none).getNumberCurrentRound()).toBe(1)
  expect(new RoundsHelper(rounds_finished_only_points).getNumberCurrentRound()).toBe(-1)
  expect(new RoundsHelper(rounds_finished_points_and_warnings).getNumberCurrentRound()).toBe(-1)
  expect(new RoundsHelper(rounds_finished_by_ko).getNumberCurrentRound()).toBe(-1)
  expect(new RoundsHelper(rounds_finished_by_ko_first_round).getNumberCurrentRound()).toBe(-1)
  expect(new RoundsHelper(rounds_second_round_current).getNumberCurrentRound()).toBe(2)
  expect(new RoundsHelper(rounds_second_round_current_only_warnings).getNumberCurrentRound()).toBe(2)
  expect(new RoundsHelper(rounds_third_round_tied).getNumberCurrentRound()).toBe(4)
  expect(new RoundsHelper(rounds_finished_by_disqualification).getNumberCurrentRound()).toBe(-1)
  expect(new RoundsHelper(rounds_finished_by_warnings).getNumberCurrentRound()).toBe(-1)
  expect(new RoundsHelper(rounds_finished_tied_5_rounds).getNumberCurrentRound()).toBe(5)
  expect(new RoundsHelper(rounds_finished_tied_3_rounds).getNumberCurrentRound()).toBe(3)
})

it('isFinished()', () => {
  expect(new RoundsHelper(rounds_none).isFinished()).toBe(false)
  expect(new RoundsHelper(rounds_finished_only_points).isFinished()).toBe(true)
  expect(new RoundsHelper(rounds_finished_points_and_warnings).isFinished()).toBe(true)
  expect(new RoundsHelper(rounds_finished_by_ko).isFinished()).toBe(true)
  expect(new RoundsHelper(rounds_finished_by_ko_first_round).isFinished()).toBe(true)
  expect(new RoundsHelper(rounds_second_round_current).isFinished()).toBe(false)
  expect(new RoundsHelper(rounds_second_round_current_only_warnings).isFinished()).toBe(false)
  expect(new RoundsHelper(rounds_third_round_tied).isFinished()).toBe(false)
  expect(new RoundsHelper(rounds_finished_by_disqualification).isFinished()).toBe(true)
  expect(new RoundsHelper(rounds_finished_by_warnings).isFinished()).toBe(true)
  expect(new RoundsHelper(rounds_finished_tied_5_rounds).isFinished()).toBe(false)
  expect(new RoundsHelper(rounds_finished_tied_3_rounds).isFinished()).toBe(false)
})

it('isTied()', () => {
  expect(new RoundsHelper(rounds_none).isTied()).toBe(false)
  expect(new RoundsHelper(rounds_finished_only_points).isTied()).toBe(false)
  expect(new RoundsHelper(rounds_finished_points_and_warnings).isTied()).toBe(false)
  expect(new RoundsHelper(rounds_finished_by_ko).isTied()).toBe(false)
  expect(new RoundsHelper(rounds_finished_by_ko_first_round).isTied()).toBe(false)
  expect(new RoundsHelper(rounds_second_round_current).isTied()).toBe(false)
  expect(new RoundsHelper(rounds_second_round_current_only_warnings).isTied()).toBe(false)
  expect(new RoundsHelper(rounds_third_round_tied).isTied()).toBe(false)
  expect(new RoundsHelper(rounds_finished_by_disqualification).isTied()).toBe(false)
  expect(new RoundsHelper(rounds_finished_by_warnings).isTied()).toBe(false)
  expect(new RoundsHelper(rounds_finished_tied_5_rounds).isTied()).toBe(true)
  expect(new RoundsHelper(rounds_finished_tied_3_rounds).isTied()).toBe(true)
})

it('getWinner()', () => {
  expect(new RoundsHelper(rounds_none).getWinner()).toBe(Winner.NONE)
  expect(new RoundsHelper(rounds_finished_only_points).getWinner()).toBe(Winner.RED)
  expect(new RoundsHelper(rounds_finished_points_and_warnings).getWinner()).toBe(Winner.RED)
  expect(new RoundsHelper(rounds_finished_by_ko).getWinner()).toBe(Winner.BLUE)
  expect(new RoundsHelper(rounds_finished_by_ko_first_round).getWinner()).toBe(Winner.BLUE)
  expect(new RoundsHelper(rounds_second_round_current).getWinner()).toBe(Winner.NONE)
  expect(new RoundsHelper(rounds_second_round_current_only_warnings).getWinner()).toBe(Winner.NONE)
  expect(new RoundsHelper(rounds_third_round_tied).getWinner()).toBe(Winner.NONE)
  expect(new RoundsHelper(rounds_finished_by_disqualification).getWinner()).toBe(Winner.BLUE)
  expect(new RoundsHelper(rounds_finished_by_warnings).getWinner()).toBe(Winner.BLUE)
  expect(new RoundsHelper(rounds_finished_tied_5_rounds).getWinner()).toBe(Winner.TIE)
  expect(new RoundsHelper(rounds_finished_tied_3_rounds).getWinner()).toBe(Winner.TIE)
})

it('getRoundsAhead()', () => {
  expect(new RoundsHelper(rounds_none).getNumberRoundsAhead()).toBe(4)
  expect(new RoundsHelper(rounds_finished_only_points).getNumberRoundsAhead()).toBe(0)
  expect(new RoundsHelper(rounds_finished_points_and_warnings).getNumberRoundsAhead()).toBe(0)
  expect(new RoundsHelper(rounds_finished_by_ko).getNumberRoundsAhead()).toBe(0)
  expect(new RoundsHelper(rounds_finished_by_ko_first_round).getNumberRoundsAhead()).toBe(0)
  expect(new RoundsHelper(rounds_second_round_current).getNumberRoundsAhead()).toBe(3)
  expect(new RoundsHelper(rounds_second_round_current_only_warnings).getNumberRoundsAhead()).toBe(3)
  expect(new RoundsHelper(rounds_third_round_tied).getNumberRoundsAhead()).toBe(1)
  expect(new RoundsHelper(rounds_finished_by_disqualification).getNumberRoundsAhead()).toBe(0)
  expect(new RoundsHelper(rounds_finished_by_warnings).getNumberRoundsAhead()).toBe(0)
  expect(new RoundsHelper(rounds_finished_tied_5_rounds).getNumberRoundsAhead()).toBe(0)
  expect(new RoundsHelper(rounds_finished_tied_3_rounds).getNumberRoundsAhead()).toBe(0)
})

it('getLastRound()', () => {
  expect(new RoundsHelper(rounds_none).getLastRound()).toStrictEqual(undefined)
  expect(new RoundsHelper(rounds_finished_only_points).getLastRound()).toStrictEqual(rounds_finished_only_points.results[4])
  expect(new RoundsHelper(rounds_finished_points_and_warnings).getLastRound()).toStrictEqual(rounds_finished_points_and_warnings.results[4])
  expect(new RoundsHelper(rounds_finished_by_ko).getLastRound()).toStrictEqual(rounds_finished_by_ko.results[1])
  expect(new RoundsHelper(rounds_finished_by_ko_first_round).getLastRound()).toStrictEqual(rounds_finished_by_ko_first_round.results[0])
  expect(new RoundsHelper(rounds_second_round_current).getLastRound()).toStrictEqual(undefined)
  expect(new RoundsHelper(rounds_second_round_current_only_warnings).getLastRound()).toStrictEqual(undefined)
  expect(new RoundsHelper(rounds_third_round_tied).getLastRound()).toStrictEqual(undefined)
  expect(new RoundsHelper(rounds_finished_by_disqualification).getLastRound()).toStrictEqual(rounds_finished_by_disqualification.results[1])
  expect(new RoundsHelper(rounds_finished_by_warnings).getLastRound()).toStrictEqual(rounds_finished_by_warnings.results[1])
  expect(new RoundsHelper(rounds_finished_tied_5_rounds).getLastRound()).toStrictEqual(undefined)
  expect(new RoundsHelper(rounds_finished_tied_3_rounds).getLastRound()).toStrictEqual(undefined)
})

const rounds_none = {
  time: 180000, //3 minuten in millisekunden
  max: 5,
  warnings: {},
  results: [] 
}

const rounds_finished_only_points = {
  time: 180000, //3 minuten in millisekunden
  max: 5,
  warnings: {},
  results: [
    {
      red: Point.ONE,
      blue: Point.FOUR
    },
    {
      red: Point.FOUR,
      blue: Point.ONE
    },
    {
      red: Point.FIVE,
      blue: Point.ZERO
    },
    {
      red: Point.THREE,
      blue: Point.TWO
    },
    {
      red: Point.ONE,
      blue: Point.FOUR
    }
  ]
}

const rounds_finished_points_and_warnings = {
  time: 180000, //3 minuten in millisekunden
  max: 5,
  warnings: {},
  results: [
    {
      red: Point.ONE,
      redWarning: Point.ONE,
      blue: Point.FOUR
    },
    {
      red: Point.FOUR,
      blue: Point.ONE
    },
    {
      red: Point.FIVE,
      blue: Point.ZERO,
      blueWarning: Point.TWO
    },
    {
      red: Point.THREE,
      blue: Point.TWO
    },
    {
      red: Point.ONE,
      blue: Point.FOUR
    }
  ]
}

const rounds_finished_by_ko = {
  time: 180000, //3 minuten in millisekunden
  max: 5,
  warnings: {},
  results: [
    {
      red: Point.ONE,
      blue: Point.FOUR
    },
    {
      blue: Point.WINNER,
      red: Point.KO
    }
  ]
}

const rounds_finished_by_ko_first_round = {
  time: 180000, //3 minuten in millisekunden
  max: 5,
  warnings: {},
  results: [
    {
      blue: Point.WINNER,
      red: Point.KO
    }
  ]
}

const rounds_second_round_current = {
  time: 180000, //3 minuten in millisekunden
  max: 5,
  warnings: {},
  results: [
    {
      red: Point.ONE,
      blue: Point.FOUR
    }
  ]
}

const rounds_second_round_current_only_warnings = {
  time: 180000, //3 minuten in millisekunden
  max: 5,
  warnings: {},
  results: [
    {
      red: Point.ONE,
      blue: Point.FOUR
    },
    {
      redWarning: Point.FOUR,
      blueWarning: Point.ONE
    }
  ]
}

const rounds_third_round_tied = {
  time: 180000, //3 minuten in millisekunden
  max: 5,
  warnings: {},
  results: [
    {
      red: Point.ONE,
      redWarning: Point.TWO,
      blue: Point.FOUR
    },
    {
      red: Point.FOUR,
      redWarning: Point.TWO,
      blue: Point.ONE
    },
    {
      red: Point.TIE,
      redWarning: Point.TWO,
      blue: Point.TIE
    }
  ]
}

const rounds_finished_by_disqualification = {
  time: 180000, //3 minuten in millisekunden
  max: 5,
  warnings: {},
  results: [
    {
      red: Point.ONE,
      blue: Point.FOUR
    },
    {
      red: Point.DISQUALIFIED,
      blue: Point.WINNER
    }
  ]
}

const rounds_finished_by_warnings = {
  time: 180000, //3 minuten in millisekunden
  max: 5,
  warnings: {},
  results: [
    {
      red: Point.ONE,
      redWarning: Point.TWO,
      blue: Point.FOUR
    },
    {
      redWarning: Point.ONE,
      red: Point.DISQUALIFIED,
      blue: Point.WINNER
    }
  ]
}

const rounds_finished_tied_5_rounds = {
  time: 180000, //3 minuten in millisekunden
  max: 5,
  warnings: {},
  results: [
    {
      red: Point.ONE,
      redWarning: Point.TWO,
      blue: Point.FOUR
    },
    {
      red: Point.ONE,
      redWarning: Point.TWO,
      blue: Point.FOUR
    },
    {
      red: Point.FOUR,
      redWarning: Point.TWO,
      blue: Point.ONE
    },
    {
      red: Point.TIE,
      redWarning: Point.TWO,
      blue: Point.TIE
    },
    {
      red: Point.FOUR,
      redWarning: Point.TWO,
      blue: Point.ONE
    }
  ]
}

const rounds_finished_tied_3_rounds = {
  time: 180000, //3 minuten in millisekunden
  max: 3,
  warnings: {},
  results: [
    {
      red: Point.ONE,
      redWarning: Point.TWO,
      blue: Point.FOUR
    },
    {
      red: Point.TIE,
      redWarning: Point.TWO,
      blue: Point.TIE
    },
    {
      red: Point.FOUR,
      redWarning: Point.TWO,
      blue: Point.ONE
    }
  ]
}
