const StartHelper = require('./StartHelper')

class FormHelper {

    constructor(form) {
        this.form = form
    }

    /**
     * Returns whether all starts already have points.
     */
    isFinished() {
        return this.form.starts.find(start => new StartHelper(start).isFinished() === false) === undefined
    }

    /**
     * Returns the form with all starts sorted by their placement. 
     * @param {*} start 
     */
    sortByPlacement() {
        const starts = this.form.starts.slice().sort((start1, start2) => {
            const start1Helper = new StartHelper(start1);
            const start2Helper = new StartHelper(start2);

            // Starter, die nicht antreten, kommen ganz nach hinten
            if (start1Helper.isDisabled() && start2Helper.isDisabled()) {
                return 0
            } else if (start1Helper.isDisabled()) {
                return 1
            } else if (start2Helper.isDisabled()) {
                return -1
            }
            
            // Starter, die noch nicht dran waren, kommen danach
            if (start1Helper.hasResult() === false && start2Helper.hasResult() === false) {
                return 0
            } else if (start1Helper.hasResult() === false) {
                return 1
            } else if (start2Helper.hasResult() === false) {
                return -1
            }

            // Schritt 1: sortieren nach Gesamtbewertung
            const valueOverallStanding1 = start1Helper.getOverallStanding()
            const valueOverallStanding2 = start2Helper.getOverallStanding()
            const deltaByOverallStanding = valueOverallStanding2 - valueOverallStanding1
            if (deltaByOverallStanding !== 0) {
                return deltaByOverallStanding
            }

            // Schritt 2: ignorierte Höchst- und Niedrigstwertung berücksichtigen
            const valueAverage1 = start1Helper.getAverage(start1.results)
            const valueAverage2 = start1Helper.getAverage(start2.results)
            const deltaByAverage = valueAverage2 - valueAverage1
            if (deltaByAverage !== 0) {
                return deltaByAverage
            }

            // Schritt 3: höchste Einzelwertung entscheidet
            const sortedResults1 = start1Helper.sortByResults('desc')
            const sortedResults2 = start2Helper.sortByResults('desc')
            const sortedResults = sortedResults1.map((result1, index) => {
                const result2 = sortedResults2[index]
                if (result2 === undefined) {
                    return []
                }
                return [result1, result2]
            })
            const highestDifferentRating = sortedResults.find(results => results[0] !== results[1])
            if (highestDifferentRating !== undefined) {
                const deltaHighestDifferentRating = highestDifferentRating[1] - highestDifferentRating[0]
                return deltaHighestDifferentRating
            }

            return 0
        })

        return {
            id: this.form.id,
            category: this.form.category,
            ring: this.form.ring,
            starts: starts
        }
    }

    /**
     * Returns the Starter without result
     */
    getStarter() {
        return this.form.starts.filter(start => new StartHelper(start).hasResult() === false)
    }

    /**
     * Returns the Starter with result
     */
    getStarterResult() {
        return this.form.starts.filter(start => new StartHelper(start).hasResult())
    }

    /**
     * Returns the top 3 starts as an array. 
     */
    getTop3() {
        const sortedByPlacement = this.sortByPlacement()
        return sortedByPlacement.starts.filter(start => new StartHelper(start).hasResult()).slice(0, 3)
    }

    /**
     * Returns the next start
     */
    getNext() {
        return this.form.starts.find(start => new StartHelper(start).isFinished() === false)
    }
}

module.exports = FormHelper