class StartHelper {
    constructor(start) {
        this.competitors = start.competitors
        this.results = start.results.filter(result => typeof result !== 'string')
        this.disabled = start.disabled !== undefined && start.disabled
    }

    /**
     * Ein Start ist beendet, wenn er entweder nicht antritt oder ein Ergebnis hat
     */
    isFinished() {
        return this.isDisabled() || this.hasResult()
    }

    /**
     * Gibt an, ob der Start nicht antritt
     */
    isDisabled() {
        return this.disabled
    }

    /**
     * Gibt an, ob dieser Start 3 oder 5 Wertungen erhalten hat
     */
    hasResult() {
        return this.results.length === 3 || this.results.length === 5
    }
    
    /**
     * Berechnet die Gesamtbewertung. Bei 5 Wertungen wird die höchste und die niedrigste Wertung ignoriert
     */
    getOverallStanding() {
        if (this.results.length === 3) {
            return this.getAverage(this.results)
        } else if (this.results.length === 5) {
            return this.getAverage(this.sortByResults().slice(1, 4))
        }
    }

    /**
     * Berechnet die Gesamtbewertung zur Anzeige auf der Obefläche.
     */
    getOverallStandingDisplay() {
        const overallStanding = this.getOverallStanding()
        if (overallStanding !== undefined) {
            return overallStanding.toFixed(2)
        }
    }

    /**
     * Berechnet den arithmetischen Durchschnitt der gegebenen Punkte
     * @param {*} points 
     */
    getAverage(points) {
        const sum = points.reduce((value, result) => value += result)
        const average = (sum/points.length).toFixed(2)
        return Number.parseFloat(average)
    }

    /**
     * Returns the results sorted by value
     * @param order asc | desc. Standard ist aufsteigend (asc)
     */
    sortByResults(order = 'asc') {
        const result = this.results.slice().sort((result1, result2) => result1 - result2)
        return order === 'desc' ? result.reverse() : result
    }

    /**
     * Erstellt komma-separierten String aller Teilnehmer
     */
    getCompetitorsDisplay() {
        return this.competitors.reduce((result, competitor) => result === undefined ? competitor : result + ', ' + competitor)
    }
}

module.exports = StartHelper