const express = require('express')
const fs = require('fs')
const cors = require('cors')

const handlebarsEngine = require('./util/handlebarsEngine')
const displayEmitter = require('./util/displayEmitter')
const logger = require('./util/logger')


// variables
displayEmitter.start()
apiDisplayChecked = 'checked'

// express
const app = express()
app.use(express.static('public'))

// set up middleware
app.use(cors())
app.use(express.json())
app.use(express.urlencoded({extended: false}))
// handlebars
app.engine('handlebars', handlebarsEngine.engine) 
app.set('view engine', 'handlebars')

// routes
app.use('/', require('./routes/home')(displayEmitter))
app.use('/api', require('./routes/api')(displayEmitter))
app.use('/forms', require('./routes/forms')(displayEmitter))
app.use('/fights', require('./routes/fights')(displayEmitter))

// server-send-event route
app.get('/tournament-manager', (req, res) => {
    logger.info(logger.LABELS.sse, req.headers.origin)

    displayEmitter.add(res)

    req.on('close', () => {
        displayEmitter.remove(res);
        res.end();
    })
    req.on('error', () => {
        displayEmitter.remove(res);
        res.end();
    })
})

const port = process.env.PORT || 5000
app.listen(port, () => console.log(`Server started on Port ${port}`))