const express = require('express')
const dataProvider = require('./../util/dataProvider')
const logger = require('./../util/logger')

module.exports = (displayEmitter) => {
    const router = express.Router()

    router.post('/sync', (req, res) => {
        logger.info(logger.LABELS.api, `/sync`)
        dataProvider.loadCompetition()
        dataProvider.loadFights()
        dataProvider.loadForms()
        res.end()
    })

    router.post('/display', (req, res) => {
        logger.info(logger.LABELS.api, `/display: ${req.body.apiDisplayChecked}`)
        apiDisplayChecked = (req.body.apiDisplayChecked === "true" ? 'checked' : '')
        res.json({success: apiDisplayChecked, status: 200});
    })

    router.post('/reset/display', (req, res) => {
        logger.info(logger.LABELS.api, '/reset/display')
        displayEmitter.send('resetDisplay')
        res.end()
    })

    router.post('/logger', (req, res) => {
        switch (req.body.level) {
            case 'info':
                logger.info(logger.LABELS.api, req.body.message)
                break
            case 'error':
                logger.error(logger.LABELS.api, req.body.message)
                break
            default:
                logger.debug(logger.LABELS.api, req.body.message)
        }
        res.end()
    })

    router.post('/form/sort', (req, res) => {
        logger.info(logger.LABELS.api, `/form/sort: [${req.body.formId}]: ${req.body.oldIndex} -> ${req.body.newIndex}`)
        const form = dataProvider.getForm(req.body.formId)
        const starts = form.starts
        const element = starts.splice(req.body.oldIndex, 1)
        starts.splice(req.body.newIndex, 0, element[0])
        dataProvider.saveForms()
        res.end()
    })
    
    router.post('/form/disable', (req, res) => {
        logger.info(logger.LABELS.api, `/form/disable: [${req.body.formId}]: [${req.body.startId}]: ${req.body.disabled}`)
        const form = dataProvider.getForm(req.body.formId)
        const start = form.starts.find(start => start.id === req.body.startId)
        start.disabled = req.body.disabled === 'true'
        dataProvider.saveForms()
        res.end()
    })
    
    router.post('/fight/sort', (req, res) => {  
        logger.info(logger.LABELS.api, `/fight/sort: ${req.body.oldIndex} -> ${req.body.newIndex}`)
        const element = dataProvider.getFights().splice(req.body.oldIndex, 1)
        dataProvider.getFights().splice(req.body.newIndex, 0, element[0])
        dataProvider.saveFights()
        res.end()
    })

    return router
}