const express = require('express')
const dataProvider = require('./../util/dataProvider')
const logger = require('./../util/logger')
const FormHelper = require('./../display/src/util/FormHelper')

module.exports = (displayEmitter) => {
    const router = express.Router()

    /**
     * Zeigt Übersicht aller Formen an, verteilt auf die Ringe
     */
    router.get('/', (req, res) => {
        logger.info(logger.LABELS.forms, '/')
        const formsSortedByRing = dataProvider.getForms().slice().sort((form1, form2) => form1.ring - form2.ring)
        res.render('forms', {
            title: `${dataProvider.getCompetition('name')}: Formen`,
            forms: formsSortedByRing,
            apiDisplayChecked
        })
    })

    /**
     * Auswahl einer Kategorie aus der Übersicht
     */
    router.post('/', (req, res) => {
        const id = req.body.displayId
        if (id) {
            res.redirect(`/forms/${id}`)
        } else {
            res.redirect('back');
        }
    })
    
    /**
     * Zeigt alle Starts einer einzelnen Kategorie
     */
    router.get('/:id', (req, res) => {
        logger.info(logger.LABELS.forms, `/:${req.params.id}`)
        const form = dataProvider.getForm(req.params.id)

        res.render('form', {
            title: `${dataProvider.getCompetition('name')}: Formen: Ring ${form.ring}: ${form.category}`,
            form,
            state: 'init',
            apiDisplayChecked,
            finished: new FormHelper(form).isFinished()
        })
    })
    
    /**
     * Reagiert auf Eintragungen in einer Form-Kategorie
     */
    router.post('/:id', (req, res) => {
        logger.info(logger.LABELS.forms, `/:${req.params.id}: ${JSON.stringify( req.body )}`)

        const form = dataProvider.getForm(req.params.id)
        
        let state
        let id

        if (req.body.show) {
            state = 'show'
            id = -1
            if (apiDisplayChecked) {
                displayEmitter.send('form', dataProvider.getCompetition(), form)
            }
        } else if (req.body.startId) {
            state = 'start'
            id = req.body.startId

            const start = form.starts.find(start => start.id === id)
            // Punkte übernehmen
            if (req.body.point1) {
                start.results = [
                    getFloat(req.body.point1),
                    getFloat(req.body.point2),
                    getFloat(req.body.point3),
                    getFloat(req.body.point4),
                    getFloat(req.body.point5)
                ]
            }
            
            if (apiDisplayChecked) {
                displayEmitter.send('start', dataProvider.getCompetition(), form, id) 
            }
        } else if (req.body.resultId) {
            state = 'result'
            id = req.body.resultId
            if (apiDisplayChecked) {
                displayEmitter.send('result', dataProvider.getCompetition(), form, id) 
            }
        }

        dataProvider.saveForms()

        res.render('form', {
            title: `${dataProvider.getCompetition('name')}: Formen: Ring ${form.ring}: ${form.category}`,
            form,
            state,
            id,
            apiDisplayChecked,
            finished: new FormHelper(form).isFinished()
        })
    })

    return router
}

function getFloat(value) {
    const result = Number.parseFloat(value)
    return Number.isNaN(result) ? '' : result
}