const EventEmitter = require('events')
const uuidv1 = require('uuid/v1')
const logger = require('./../util/logger')

emitter = new EventEmitter()

const clients = []
let messageCounter = 1

onKeepAlive = () => {
    clients.map(res => {
        res.write('event: keepalive\n')
        res.write(`id: ${messageCounter}\n`)
        res.write(`data: ${JSON.stringify('')}`)
        res.write('\n\n')
    })
}

// 0000356: Restarting clients
onResetDisplay = () => {
    clients.map(res => {
        res.write('event: resetdisplay\n')
        res.write(`id: ${messageCounter}\n`)
        res.write(`data: ${JSON.stringify('')}`)
        res.write('\n\n')
    })
}

onForm = (competition, form, start) => {
    clients.map(res => {
        res.write('event: form\n')
        res.write(`id: ${messageCounter}\n`)
        res.write(`data: ${JSON.stringify({competition, form, start})}`)
        res.write('\n\n')
    })
}
onStart = (competition, form, id) => {
    clients.map(res => {
        res.write('event: start\n')
        res.write(`id: ${messageCounter}\n`)
        res.write(`data: ${JSON.stringify({competition, form, id})}`)
        res.write('\n\n')
    })
}
onResult = (competition, form, id) => {
    clients.map(res => {
        res.write('event: result\n')
        res.write(`id: ${messageCounter}\n`)
        res.write(`data: ${JSON.stringify({competition, form, id})}`)
        res.write('\n\n')
    })
}

onFights = (competition, fights) => {
    clients.map(res => {
        res.write('event: fights\n')
        res.write(`id: ${messageCounter}\n`)
        res.write(`data: ${JSON.stringify({competition, fights})}`)
        res.write('\n\n')
    })
}
onFight = (competition, fights, fight) => {
    clients.map(res => {
        res.write('event: fight\n')
        res.write(`id: ${messageCounter}\n`)
        res.write(`data: ${JSON.stringify({competition, fights, id: fight.id})}`)
        res.write('\n\n')
    })
}

const start = () => {
    logger.info(logger.LABELS.emit, 'start')

    // keepAlive feuert alle 2,5 Minuten
    this.keepAliveInterval = setInterval(() => {
        emitter.emit('keepAlive')
    }, 105000)
    
    emitter.on('keepAlive', onKeepAlive)
    emitter.on('resetDisplay', onResetDisplay)
    
    emitter.on('form', onForm)
    emitter.on('result', onResult)
    emitter.on('start', onStart)
    
    emitter.on('fights', onFights)
    emitter.on('fight', onFight)
}

const stop = () => {
    logger.info(logger.LABELS.emit, 'stop')
    emitter.removeListener('keepAlive', onKeepAlive)
    clearInterval(this.keepAliveInterval)
    emitter.removeListener('resetDisplay', onResetDisplay)

    emitter.removeListener('form', onForm)
    emitter.removeListener('start', onStart)
    emitter.removeListener('result', onResult)

    emitter.removeListener('fights', onFights)
    emitter.removeListener('fight', onFight)
}

const add = (res) => {
    res._uid = uuidv1()
    logger.info(logger.LABELS.emit, `add: ${res._uid}`)
    
    res.writeHead(200, {
        'Connection': 'keep-alive',
        'Content-Type': 'text/event-stream',
        'Cache-Control': 'no-cache',
        'X-Accel-Buffering': 'no'
    });

    clients.push(res)
}

const send = (event, ...args) => {
    logger.info(logger.LABELS.emit, `${messageCounter}: ${event}`)
    logger.debug(logger.LABELS.emit, `${JSON.stringify(args)}`)

    clients.map(res => {
        if (res.finished) {
            remove(res)
        }
    })

    emitter.emit(event, ...args)
    messageCounter ++
}

const remove = (res) => {
    logger.info(logger.LABELS.emit, `remove: ${res._uid}`)
    const index = clients.findIndex(client => client._uid === res._uid)
    if (index > -1) {
        clients.splice(index, 1)
    }
}
 
module.exports = {
    start,
    stop,
    add,
    send,
    remove
}