const exphbs = require('express-handlebars')

const FightsHelper = require('./../display/src/util/FightsHelper')
const RoundsHelper = require('./../display/src/util/RoundsHelper')
const RoundHelper = require('./../display/src/util/RoundHelper')
const FormHelper = require('./../display/src/util/FormHelper')
const StartHelper = require('./../display/src/util/StartHelper')

module.exports = handlebarsEngine = exphbs.create({
    defaultLayout: 'main',
    helpers: {
        times: (value, block) => {
            let accum = ''
            for (let i = 0; i < value; ++i) {
                accum += block.fn(i)
            }
            return accum
        },
        increment: value => parseInt(value) + 1,
        add: (a, b) => parseInt(a) + parseInt(b),
        pointToString: (point, code) => point.type === 'point' ? code.repeat(point.value) : point.display,
        roundStyling: (round) => `${new RoundHelper(round).getWinner().bg} ${new RoundHelper(round).getWinner().textColor}`,
        fightStyling: (fights, fight) => {
            const fightsHelper = new FightsHelper(fights)
            if (fightsHelper.isCurrent(fight.id)) {
                return 'bg-black text-white border border-3'
            } else {
                const roundsHelper = new RoundsHelper(fight.rounds)
                const winner = roundsHelper.getWinner()
                return `${winner.bg} ${winner.textColor}`
            }
        },
        getRed: (fights, fight) => new FightsHelper(fights).getRed(fight.id),
        getBlue: (fights, fight) => new FightsHelper(fights).getBlue(fight.id),
        formStyling: (form) => {
            const formHelper = new FormHelper(form)
            if (formHelper.isFinished()) {
                return 'bg-gray text-white'
            }
            return 'bg-white text-black'
        },
        startStyling: (form, start) => {
            const formHelper = new FormHelper(form)
            const next = formHelper.getNext()
            if (next != undefined && next.id === start.id) {
                return 'bg-black text-white'
            }
            return 'bg-white text-black'
            
        },
        handleState: (state, id) => {
            switch (state) {
                case 'init':
                    return 'init()'
                case 'show':
                    return 'show()'
                case 'start':
                    return `start('${id}')`
                case 'result':
                    return 'result()'
                default:
                    return 'init()'
            }
        },
        getDisplayClass: () => {
            const defaultClasses = 'btn text-black font-weight-bold id-display'
            return apiDisplayChecked ? defaultClasses + ' btn-info' : defaultClasses + ' btn-warning'
        },
        getOverallStandingDisplay: (start) => {
            return new StartHelper(start).getOverallStandingDisplay()
        }
    }
})