const moment = require('moment')
const winston = require('winston')
require('winston-daily-rotate-file')
const { combine, timestamp, printf } = winston.format

moment.locale('de')

const errorTransport = new winston.transports.DailyRotateFile({
    dirname: './logs',
    filename: 'error.%DATE%.log',
    datePattern: 'YYYY-MM-DD',
    zippedArchive: false,
    maxSize: '20m',
    maxFiles: '14d',
    level: 'error'
})

const combinedTransport = new winston.transports.DailyRotateFile({
    dirname: './logs',
    filename: 'combined.%DATE%.log',
    datePattern: 'YYYY-MM-DD',
    zippedArchive: false,
    maxSize: '20m',
    maxFiles: '14d'
})


const loggingFormat = printf(({ level, message, label, timestamp }) => `${timestamp} [${label}] ${level}: ${message}`)
const tournamentManagerLogger = winston.createLogger({
    format: combine(timestamp(), loggingFormat),
    level: 'debug',
    transports: [
        errorTransport, combinedTransport
    ]
})

const logger = {
    LABELS: { sse: 'sse', home: 'home', forms: 'forms', fights: 'fights', api: 'api', emit: 'emit'},
    error: (label, message) => tournamentManagerLogger.error({timestamp: moment().format('lll'), label, message}),
    info: (label, message) => tournamentManagerLogger.info({timestamp: moment().format('lll'), label, message}),
    debug: (label, message) => tournamentManagerLogger.debug({timestamp: moment().format('lll'), label, message})
}

module.exports = logger